@@ -3,10 +3,11 @@
 #' @description \code{compare.methods} creates graphs to visually assess performance of acoustic distance measurements 
 #' @usage compare.methods(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1, wl = 512, ovlp = 90, 
 #' res = 150, n = 10, length.out = 30, 
-#' methods = c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC"), 
-#' it = "jpeg", parallel = 1, path = NULL, sp = NULL, pb = TRUE, grid = TRUE, 
-#' clip.edges = TRUE, threshold = 15, na.rm = FALSE, scale = FALSE,
-#'  pal = reverse.gray.colors.2, img = TRUE, ...)
+#' methods = NULL, 
+#' it = "jpeg", parallel = 1, path = NULL, sp = NULL, custom1 = NULL, 
+#' custom2 = NULL, pb = TRUE, grid = TRUE,  clip.edges = TRUE, 
+#' threshold = 15, na.rm = FALSE, scale = FALSE, pal = reverse.gray.colors.2, 
+#' img = TRUE, ...)
 #' @param X 'selection_table' object or data frame with results from \code{\link{manualoc}} function, \code{\link{autodetec}} 
 #' function, or any data frame with columns for sound file name (sound.files), 
 #' selection number (selec), and start and end time of signal (start and end).
@@ -36,14 +37,18 @@
 #'    \item \code{SPharm}: spectral parameters (\code{\link{specan}} function with argument \code{harmonicity  = TRUE})
 #'    \item \code{MFCC}: statistical descriptors of Mel frequency cepstral coefficients (\code{\link{mfcc_stats}} function)
 #'    }
+#'  Default \code{NULL}. 
 #' @param it A character vector of length 1 giving the image type to be used. Currently only
 #' "tiff" and "jpeg" are admitted. Default is "jpeg".
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #'  It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
 #' @param path Character string containing the directory path where the sound files are located. 
 #' If \code{NULL} (default) then the current working directory is used. 
-#' @param sp Data frame with acoustic parameters as the one generated by \code{\link{specan}}. Must contain 'sound.files'
-#' and "selec' columns and the same selections as in 'X'.
+#' @param sp TO BE DEPRECATED. Use "custom1" and "custom2" argumentsinstead.
+#' @param custom1 Data frame containing user parameters. The data frame must have 4 columns: the first 2 columns are 'sound.files'
+#' and "selec' columns as in 'X', the other 2 (columns 3 and 4) are
+#' 2 numeric columns to be used as the 2 parameters representing custom measurements. If the data has more than 2 parameters try using PCA (i.e. \code{\link[stats]{prcomp}} function)to summarize it in 2 dimensions before using it as an input. Default is \code{NULL}.
+#' @param custom2 Data frame containing user parameters with the same format as 'custom1'. 'custom1' must be provided first. Default is \code{NULL}.   
 #' @param pb Logical argument to control progress bar. Default is \code{TRUE}.
 #' @param grid Logical argument to control the presence of a grid on the spectrograms (default is \code{TRUE}).
 #' @param clip.edges Logical argument to control whether edges (start or end of signal) in
@@ -78,19 +83,19 @@
 #' warping on dominant frequency time series (ffDTW, from \code{\link[dtw]{dtw}} applied on 
 #' \code{\link{ffts}} output), spectral parameters (SP, from \code{\link{specan}}). The graph also 
 #' contains 2 scatterplots (1 for each method) of the acoustic space of all signals in the 
-#' input data frame 'X'. The compared selections are randomly picked up from the pool of 
+#' input data frame 'X', including the centroid as black dot. The compared selections are randomly picked up from the pool of 
 #' selections in the input data frame. The argument 'n' defines the number of comparisons (i.e. graphs) 
 #' to be produced. The acoustic pairwise distance between signals is shown next 
 #' to the arrows linking them. The font color of a distance value correspond to the font 
 #' color of the method that generated it, as shown in the scatterplots. Distances are 
 #' standardized, being 0 the distance of a signal to itself and 1 the farthest pairwise 
 #' distance in the pool of signals. Principal Component Analysis (\code{\link[stats]{prcomp}}) 
-#' is applied to calculate distances when using spectral parameters (SP). In that case the first 2 PC's are used. Classical 
+#' is applied to calculate distances when using spectral parameters (SP) and descriptors of cepstral coefficients (MFCC). In those cases the first 2 PC's are used. Classical 
 #' Multidimensional Scalling (also known as Principal Coordinates Analysis, 
-#' (\code{\link[stats]{cmdscale}})) is used for all other methods. The graphs are return as image files in the 
+#' (\code{\link[stats]{cmdscale}})) is used for cross-correlation (XCORR) and any dynamic time warping method. The graphs are return as image files in the 
 #' working directory. The file name contains the methods being compared and the 
-#' rownumber of the selections. This function uses internally a modified version
-#' of the \code{\link[seewave]{spectro}} function from seewave package to create spectrograms.
+#' row number of the selections. This function uses internally a modified version
+#' of the \code{\link[seewave]{spectro}} function from seewave package to create spectrograms. Custom data can also be compared against the avialable methods (or against each other) using the arguments 'custom1' and 'custom2'.
 #' @seealso \href{https://marce10.github.io/2017/02/17/Choosing_the_right_method_for_measuring_acoustic_signal_structure.html}{blog post on comparing methods}
 #' @examples
 #' \dontrun{
@@ -125,17 +130,18 @@
 #' methods = c("dfDTW", "SP"), parallel = 1, it = "jpeg")
 #' 
 #' #alternatively we can provide our own SP matrix
-#' sp <- specan(lbh_selec_table, bp = c(0, 10))
+#' Y <- specan(lbh_selec_table)
 #' 
-#' #and selec just a few variables to avoid the problem of # observations vs # parameters in PCA
-#' sp <- sp[, 1:7]
+#' # selec a subset of variables
+#' Y <- Y[, 1:7]
 #' 
-#' compare.methods(X = lbh_selec_table, flim = c(0, 10), sp = sp, bp = c(0, 10), mar = 0.1, wl = 300,
-#' ovlp = 90, res = 200, n = 10, length.out = 30,
-#' methods = c("XCORR", "SP"), parallel = 1, it = "jpeg")
+#' # PCA
+#' Y <- prcomp(Y[, 3:ncol(Y)])$x
 #' 
-#' #note that "SP" should also be included as a method in 'methods'
-#' #again, all images are saved in the working directory
+#' # add sound files and selec columns
+#' Y <- data.frame(lbh_selec_table[, c(1, 3)], Y[, 1:2])
+#' 
+#' compare_methods(X = lbh_selec_table, methods = c("dfDTW"), custom1 = Y)
 #' }
 #' 
 #' @references {Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.}
@@ -145,8 +151,8 @@
 #last modification on mar-13-2018 (MAS)
 
 compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1, wl = 512, ovlp = 90, 
-    res = 150, n = 10, length.out = 30, methods = c("XCORR","dfDTW", "ffDTW", "SP", "SPharm", "MFCC"),
-    it = "jpeg", parallel = 1, path = NULL, sp = NULL, pb = TRUE, grid = TRUE, 
+    res = 150, n = 10, length.out = 30, methods = NULL,
+    it = "jpeg", parallel = 1, path = NULL, sp = NULL, custom1 = NULL, custom2 = NULL, pb = TRUE, grid = TRUE, 
     clip.edges = TRUE, threshold = 15, na.rm = FALSE, scale = FALSE, 
     pal = reverse.gray.colors.2, img = TRUE, ...){  
  
@@ -158,7 +164,7 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   argms <- methods::formalArgs(compare.methods)
   
   # get warbleR options
-  opt.argms <- if(!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
+  opt.argms <- if (!is.null(getOption("warbleR"))) getOption("warbleR") else SILLYNAME <- 0
   
   options(warn = -1)
   on.exit(options(warn = 0), add = TRUE)
@@ -198,20 +204,28 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   if (!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
   if (any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
-  # methods 
-  if (any(!is.character(methods),length(methods) > 2)) stop("'methods' must be a character vector of length 2")
-  if (length(methods[!methods %in% c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC")]) > 0) 
-    stop(paste(methods[!methods %in% c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC")],"is (are) not valid method"))
+  # methods
+  if(is.null(methods)){
+    if (is.null(custom1) & is.null(custom2)) stop("'methods' or custom data should be provided") else methods <- c(NA, NA)
+    } else {  
+      if (length(methods) < 2 & is.null(custom1) & is.null(custom2)) stop("must provide 2 methods or custom data")
+      if (length(methods) > 1 & !is.null(custom1) & is.null(custom2)) stop("only 1 method needed")
+  if (length(setdiff(methods, c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC"))) > 0) 
+    stop(paste(setdiff(methods, c("XCORR", "dfDTW", "ffDTW", "SP", "SPharm", "MFCC")), "is (are) not valid method(s)"))
+  }
+
   
   #if flim is not vector or length!=2 stop
-  if (!is.null(flim))
-  {if (!is.vector(flim)) stop("'flim' must be a numeric vector of length 2") else{
-    if (!length(flim) == 2) stop("'flim' must be a numeric vector of length 2")}}    
+  if (!is.null(flim)){
+    if (!is.vector(flim)) stop("'flim' must be a numeric vector of length 2") else{
+    if (!length(flim) == 2) stop("'flim' must be a numeric vector of length 2")}
+    }    
  
   #if bp is not vector or length!=2 stop
-  if (!is.null(bp))
-  {if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
-    if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}} 
+  if (!is.null(bp)){
+    if (!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
+    if (!length(bp) == 2) stop("'bp' must be a numeric vector of length 2")}
+    } 
   
   #if wl is not vector or length!=1 stop
   if (is.null(wl)) stop("'wl' must be a numeric vector of length 1") else {
@@ -257,30 +271,66 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   
   #check sp data frame
   if (!is.null(sp))
-  {if (!is.data.frame(sp)) stop("'sp' must be a data frame") 
-    if (nrow(sp) != nrow(X)) stop("'sp' must have the same number of selections than X") 
-    if (!all(c("sound.files", "selec") %in% names(sp))) stop("'sound.files' or 'selec' columns missing in 'sp'")
-  } 
+    stop("'sp' has been deprecated. Use 'custom1' instead") 
+    
+  #check custom1 data frame
+  if (!is.null(custom1)){
+    if (!is.data.frame(custom1)) stop("'custom1' must be a data frame") 
+    if (nrow(custom1) != nrow(X)) stop("'custom1' must have the same number of selections than X") 
+    if (ncol(custom1) != 4) stop("'custom1' must have 4 columns") 
+    if (!all(c("sound.files", "selec") %in% names(custom1))) stop("'sound.files' or 'selec' columns missing in 'custom1'")
+    
+    # over write method names
+    if (is.null(custom2))
+    methods[2] <- "custom1" else
+      methods[1] <- "custom1"
+    } 
+
+  #check custom2 data frame
+  if (!is.null(custom2)){
+    if (!is.null(custom2) & is.null(custom1)) stop("please provide 'custom1' first") 
+    if (!is.data.frame(custom2)) stop("'custom1' must be a data frame") 
+    if (nrow(custom2) != nrow(X)) stop("'custom1' must have the same number of selections than X") 
+    if (ncol(custom2) != 4) stop("'custom2' must have 4 columns") 
+    if (!all(c("sound.files", "selec") %in% names(custom2))) stop("'sound.files' or 'selec' columns missing in 'custom1'")
   
+    methods[2] <- "custom2"
+    } 
+    
   #if it argument is not "jpeg" or "tiff" 
   if (!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
 
   #create empty list for method results
-  disim.mats <- list()
+  bidims <- list()
   
-  if ("XCORR" %in% methods)
-  {xcmat <- xcorr(X, wl = wl, bp = bp, ovlp = ovlp, dens = 0.9, parallel = parallel, pb = pb, na.rm = na.rm, cor.mat = TRUE)
+  if ("custom1" %in% methods) { 
+    if (anyNA(custom1)) stop("NAs were found in 'custom1'")
+    
+    custom1 <- custom1[match(paste(X$sound.files, X$selec), paste(custom1$sound.files, custom1$selec)), ]
+    
+    bidims[[length(bidims) + 1]] <- custom1[, 3:4]
+  }
+  
+  if ("custom2" %in% methods) { 
+    if (anyNA(custom2)) stop("NAs were found in 'custom2'")
+    
+    custom2 <- custom2[match(paste(X$sound.files, X$selec), paste(custom2$sound.files, custom2$selec)), ]
+    
+    bidims[[length(bidims) + 1]] <- custom2[, 3:4]
+  }
+  
+  if ("XCORR" %in% methods){
+    xcmat <- xcorr(X, wl = wl, bp = bp, ovlp = ovlp, dens = 0.9, parallel = parallel, pb = pb, na.rm = na.rm, cor.mat = TRUE)
 
   MDSxcorr <- stats::cmdscale(1-xcmat)  
   MDSxcorr <- scale(MDSxcorr)
-  disim.mats[[1]] <- MDSxcorr
+  bidims[[length(bidims) + 1]] <- MDSxcorr
   
   #remove the ones that failed cross-corr
   if (na.rm) X <- X[paste(X$sound.files, X$selec, sep = "-") %in% rownames(MDSxcorr), ]
     }
   
-  if ("dfDTW" %in% methods)
-    {
+  if ("dfDTW" %in% methods){
     if (pb)   write(file = "", x = "measuring dominant frequency contours:")
     dtwmat <- dfts(X, wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out,
                     pb = pb, clip.edges = clip.edges, threshold = threshold)
@@ -294,11 +344,10 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   
   MDSdtw <- stats::cmdscale(dm)  
   MDSdtw <- scale(MDSdtw)
-  disim.mats[[length(disim.mats) + 1]] <- MDSdtw
+  bidims[[length(bidims) + 1]] <- MDSdtw
   }
 
-  if ("ffDTW" %in% methods)
-  {
+  if ("ffDTW" %in% methods){
    if (pb)  write(file = "", x ="measuring fundamental frequency contours:")
     dtwmat <- ffts(X, wl = wl, flim = flim, ovlp = ovlp, img = FALSE, parallel = parallel, length.out = length.out,
                   pb = pb, clip.edges = clip.edges, threshold = threshold)
@@ -312,32 +361,28 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   
   MDSdtw <- stats::cmdscale(dm)  
   MDSdtw <- scale(MDSdtw)
-  disim.mats[[length(disim.mats) + 1]] <- MDSdtw
+  bidims[[length(bidims) + 1]] <- MDSdtw
   }
   
-  if ("SP" %in% methods)
-  { if (is.null(sp)) {
+  if ("SP" %in% methods) { 
     if (pb) write(file = "", x ="measuring spectral parameters:")
-    spmat <- specan(X, wl = wl, bp = bp, parallel = parallel, pb = pb, threshold = threshold, harmonicity = FALSE)} else spmat <- sp
+    spmat <- specan(X, wl = wl, bp = bp, parallel = parallel, pb = pb, threshold = threshold, harmonicity = FALSE)
   
   PCsp <- prcomp(scale(spmat[,3:ncol(spmat)]), center = TRUE, scale. = TRUE, rank. = 2)$x
 
-  disim.mats[[length(disim.mats) + 1]] <- PCsp
+  bidims[[length(bidims) + 1]] <- PCsp
   }
   
-  if ("SPharm" %in% methods)
-  { 
+  if ("SPharm" %in% methods){ 
     if (pb) write(file = "", x ="measuring spectral parameters + harmonicity:")
     spmat <- specan(X, wl = wl, bp = bp, parallel = parallel, pb = pb, threshold = threshold, harmonicity = TRUE)
    
     PCsp <- prcomp(scale(spmat[,3:ncol(spmat)]), center = TRUE, scale. = TRUE, rank. = 2)$x
-    
-    
-    disim.mats[[length(disim.mats) + 1]] <- PCsp
+  
+    bidims[[length(bidims) + 1]] <- PCsp
   }
   
-  if ("MFCC" %in% methods)
-  { 
+  if ("MFCC" %in% methods) { 
     if (pb) write(file = "", x ="measuring cepstral coefficients:")
     mfcc <- mfcc_stats(X, wl = wl, bp = bp, parallel = parallel, pb = pb)
     
@@ -345,17 +390,17 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
 
     PCmfcc <- prcomp(mfcc[, 3:ncol(mfcc)], center = TRUE, scale. = TRUE, rank. = 2)$x
     
-    disim.mats[[length(disim.mats) + 1]] <- PCmfcc
+    bidims[[length(bidims) + 1]] <- PCmfcc
   }
   
   #name matchs changing order to match order in whic methods are ran
-  nms <- match(c("XCORR","dfDTW", "ffDTW", "SP", "SPharm", "MFCC"), methods)
+  nms <- match(c("custom1", "custom2", "XCORR","dfDTW", "ffDTW", "SP", "SPharm", "MFCC"), methods)
   
   # add names
-  names(disim.mats) <- c("XCORR","dfDTW", "ffDTW", "SP", "SPharm", "MFCC")[!is.na(nms)] 
+  names(bidims) <- c("custom1", "custom2", "XCORR","dfDTW", "ffDTW", "SP", "SPharm", "MFCC")[!is.na(nms)] 
   
   #
-  maxdist <-lapply(disim.mats, function(x) max(stats::dist(x)))
+  maxdist <-lapply(bidims, function(x) max(stats::dist(x)))
   
   X$labels <- 1:nrow(X)
   
@@ -388,20 +433,20 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
   # screen 7:9 for similarities/arrows
   # screen 10:11 method labels
   
-      comp.methFUN <- function(X, u, res, disim.mats, m, mar, flim)
+      comp.methFUN <- function(X, u, res, bidims, m, mar, flim)
     {
     rs <- combs[,u]
     X <- X[rs,]
   
        if (img)
-         img_wrlbr_int(filename = paste("comp.meth-", names(disim.mats)[1],"-",names(disim.mats)[2], "-", paste(X$labels, collapse = "-"), paste0(".", it), sep = ""), path = path, width = 16.25, height =  16.25, units = "cm", res = res)
+         img_wrlbr_int(filename = paste("comp.meth-", names(bidims)[1],"-",names(bidims)[2], "-", paste(X$labels, collapse = "-"), paste0(".", it), sep = ""), path = path, width = 16.25, height =  16.25, units = "cm", res = res)
   
   graphics::split.screen(m)
   
   mxdur<-max(X$end - X$start) + mar*2
   
   #set colors for numbers in scatterplots and spectrograms
-  col <- rep("gray40", nrow(disim.mats[[1]]))
+  col <- rep("gray40", nrow(bidims[[1]]))
   
   col <- adjustcolor(col, alpha.f = 0.5)
   
@@ -452,24 +497,24 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
     
     #upper left
     if (x == 5) {
-      plot(disim.mats[[1]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(disim.mats[[1]][,1]) * 1.1, max(disim.mats[[1]][,1]) * 1.1), ylim = c(min(disim.mats[[1]][,2]) * 1.1, max(disim.mats[[1]][,2]) * 1.1))
+      plot(bidims[[1]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(bidims[[1]][,1]) * 1.1, max(bidims[[1]][,1]) * 1.1), ylim = c(min(bidims[[1]][,2]) * 1.1, max(bidims[[1]][,2]) * 1.1))
       box(lwd = 4)
-      centro <- apply(disim.mats[[1]], 2, mean)
+      centro <- apply(bidims[[1]], 2, mean)
       points(centro[1], centro[2], pch = 20, cex = 2, col = "gray3")
-      cex <- rep(1, nrow(disim.mats[[1]]))
+      cex <- rep(1, nrow(bidims[[1]]))
       cex[rs] <- 1.4
-      text(disim.mats[[1]],  labels = 1:nrow(disim.mats[[1]]), col = col, cex =cex, font = 2)
+      text(bidims[[1]],  labels = 1:nrow(bidims[[1]]), col = col, cex =cex, font = 2)
     }
     
     #upper right
     if (x == 6) {
-      plot(disim.mats[[2]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(disim.mats[[2]][,1]) * 1.1, max(disim.mats[[2]][,1]) * 1.1), ylim = c(min(disim.mats[[2]][,2]) * 1.1, max(disim.mats[[2]][,2]) * 1.1))
+      plot(bidims[[2]], col = "white", xaxt = "n", yaxt = "n", xlim = c(min(bidims[[2]][,1]) * 1.1, max(bidims[[2]][,1]) * 1.1), ylim = c(min(bidims[[2]][,2]) * 1.1, max(bidims[[2]][,2]) * 1.1))
       box(lwd = 4)
-      centro <- apply(disim.mats[[2]], 2, mean)
+      centro <- apply(bidims[[2]], 2, mean)
       points(centro[1], centro[2], pch = 20, cex = 2, col = "gray3")
-      cex <- rep(1, nrow(disim.mats[[2]]))
+      cex <- rep(1, nrow(bidims[[2]]))
       cex[rs] <- 1.4
-      text(disim.mats[[2]],  labels = 1:nrow(disim.mats[[2]]), col = col, cex =cex, font = 2)
+      text(bidims[[2]],  labels = 1:nrow(bidims[[2]]), col = col, cex =cex, font = 2)
     }  
     
     #lower mid
@@ -478,17 +523,17 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       lim <- par("usr")
       rect(lim[1], lim[3]-1, lim[2], lim[4]+1, border = adjustcolor("#EFAA7B", alpha.f = 0), col = adjustcolor("#EFAA7B", alpha.f = 0.15))
       arrows(0, 5.5/7, 1, 5.5/7, code = 3, length = 0.09, lwd = 2)
-      text(0.5, 5.36/7,labels =round(stats::dist(disim.mats[[1]][rs[c(1,2)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
-      text(0.5, 5.545/7,labels =round(stats::dist(disim.mats[[2]][rs[c(1,2)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
+      text(0.5, 5.36/7,labels =round(stats::dist(bidims[[1]][rs[c(1,2)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
+      text(0.5, 5.545/7,labels =round(stats::dist(bidims[[2]][rs[c(1,2)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
       arrows(0, 1.5/7, 1, 1.5/7, code = 3, length = 0.09, lwd = 2)
-      text(0.5, 1.4/7,labels = round(stats::dist(disim.mats[[1]][rs[c(3,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
-      text(0.5, 1.63/7,labels =round(stats::dist(disim.mats[[2]][rs[c(3,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
+      text(0.5, 1.4/7,labels = round(stats::dist(bidims[[1]][rs[c(3,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
+      text(0.5, 1.63/7,labels =round(stats::dist(bidims[[2]][rs[c(3,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
       arrows(0, 2/7, 1, 5/7, code = 3, length = 0.09, lwd = 2)
-      text(0.69, 4.16/7,labels =round(stats::dist(disim.mats[[1]][rs[c(2,3)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
-      text(0.85, 4.4/7,labels =round(stats::dist(disim.mats[[2]][rs[c(2,3)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
+      text(0.69, 4.16/7,labels =round(stats::dist(bidims[[1]][rs[c(2,3)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
+      text(0.85, 4.4/7,labels =round(stats::dist(bidims[[2]][rs[c(2,3)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)
       arrows(0, 5/7, 1, 2/7, code = 3, length = 0.09, lwd = 2)
-      text(0.3, 4.16/7,labels =round(stats::dist(disim.mats[[1]][rs[c(1,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
-      text(0.15, 4.4/7,labels =round(stats::dist(disim.mats[[2]][rs[c(1,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)  
+      text(0.3, 4.16/7,labels =round(stats::dist(bidims[[1]][rs[c(1,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 3)
+      text(0.15, 4.4/7,labels =round(stats::dist(bidims[[2]][rs[c(1,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 1)  
     }
     
     #in between left
@@ -497,8 +542,8 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       lim <- par("usr")
       rect(lim[1], lim[3]-1, lim[2], lim[4]+1, border = adjustcolor("#EFAA7B", alpha.f = 0.15), col = adjustcolor("#EFAA7B", alpha.f = 0.15))
       arrows(0.5, 0, 0.5, 1, code = 3, length = 0.09, lwd = 2)
-      text(0.53, 0.5, labels =round(stats::dist(disim.mats[[1]][rs[c(1,3)],])/maxdist[[1]],2), col = "black", font = 2, pos = 2)
-      text(0.47, 0.5, labels =round(stats::dist(disim.mats[[2]][rs[c(1,3)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 4)
+      text(0.53, 0.5, labels =round(stats::dist(bidims[[1]][rs[c(1,3)],])/maxdist[[1]],2), col = "black", font = 2, pos = 2)
+      text(0.47, 0.5, labels =round(stats::dist(bidims[[2]][rs[c(1,3)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 4)
     }
     
     #in between right
@@ -507,8 +552,8 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       lim <- par("usr")
       rect(lim[1], lim[3]-1, lim[2], lim[4]+1, border = adjustcolor("#EFAA7B", alpha.f = 0.15), col = adjustcolor("#EFAA7B", alpha.f = 0.15))
       arrows(0.5, 0, 0.5, 1, code = 3, length = 0.09, lwd = 2)
-      text(0.53, 0.5,labels =round(stats::dist(disim.mats[[1]][rs[c(2,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 2)
-      text(0.47, 0.5,labels =round(stats::dist(disim.mats[[2]][rs[c(2,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 4)
+      text(0.53, 0.5,labels =round(stats::dist(bidims[[1]][rs[c(2,4)],])/maxdist[[1]],2), col = "black", font = 2, pos = 2)
+      text(0.47, 0.5,labels =round(stats::dist(bidims[[2]][rs[c(2,4)],])/maxdist[[2]],2), col = "gray50", font = 2, pos = 4)
       
     }
     
@@ -517,7 +562,7 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       plot(0.5, xlim = c(0,1), ylim = c(0,1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
       lim <- par("usr")
       rect(lim[1], lim[3]-1, lim[2], lim[4]+1, border = "black", col = adjustcolor("#4ABDAC", alpha.f = 0.3))
-        text(0.5, 0.5, labels = names(disim.mats)[1], col = 'black', font = 2, cex = 1.2)
+        text(0.5, 0.5, labels = names(bidims)[1], col = 'black', font = 2, cex = 1.2)
         box(lwd = 4)
         }
     
@@ -525,7 +570,7 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       plot(0.5, xlim = c(0,1), ylim = c(0,1), type = "n", axes = FALSE, xlab = "", ylab = "", xaxt = "n", yaxt = "n")
       lim <- par("usr")
       rect(lim[1], lim[3]-1, lim[2], lim[4]+1, border = "black", col = adjustcolor("#4ABDAC", alpha.f = 0.3))
-      text(0.5, 0.5, labels = names(disim.mats)[2], col = 'gray50', font = 2, cex = 1.2)      
+      text(0.5, 0.5, labels = names(bidims)[2], col = 'gray50', font = 2, cex = 1.2)      
       box(lwd = 4)
     }
   }
@@ -547,7 +592,7 @@ compare.methods <- function(X = NULL, flim = c(0, 22), bp = c(0, 22), mar = 0.1,
       
       a1 <- pbapply::pblapply(X = 1:ncol(combs), cl = cl, FUN = function(u) 
       { 
-        comp.methFUN(X, u, res, disim.mats, m, mar, flim)
+        comp.methFUN(X, u, res, bidims, m, mar, flim)
       })
       }
 
