@@ -73,23 +73,20 @@
 #' @name seltailor
 #' @examples
 #' \dontrun{
-#' #Set temporary working directory
-#' # setwd(tempdir())
+#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4", "lbh_selec_table"))
+#' writeWave(Phae.long1, file.path(tempdir(), "Phae.long1.wav"))
+#' writeWave(Phae.long2, file.path(tempdir(), "Phae.long2.wav"))
+#' writeWave(Phae.long3, file.path(tempdir(), "Phae.long3.wav"))
+#' writeWave(Phae.long4, file.path(tempdir(), "Phae.long4.wav"))
 #' 
-#' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4", "selec.table"))
-#' writeWave(Phae.long1,"Phae.long1.wav")
-#' writeWave(Phae.long2,"Phae.long2.wav")
-#' writeWave(Phae.long3,"Phae.long3.wav")
-#' writeWave(Phae.long4,"Phae.long4.wav")
-#' 
-#' seltailor(X =  selec.table, flim = c(1,12), wl = 300, auto.next = TRUE)
+#' seltailor(X =  lbh_selec_table, flim = c(1,12), wl = 300, auto.next = TRUE, path = tempdir())
 #' 
 #' # Read output .csv file
-#' seltailor.df <- read.csv("seltailor_output.csv")
+#' seltailor.df <- read.csv(file.path(tempdir(), "seltailor_output.csv"))
 #' seltailor.df
 #' 
 #' # check this directory for .csv file after stopping function
-#' getwd()
+#' tempdir()
 #' }
 #' @details This function produces an interactive spectrographic
 #'  view in which users can select new time/frequency 
@@ -122,7 +119,7 @@
 #' @references {
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
 #' }
-#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
+#' @author Marcelo Araya-Salas (\email{marceloa27@@gmail.com})
 #last modification on jul-5-2016 (MAS)
 
 seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar = 0.5,
@@ -133,9 +130,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
                        ts.df = NULL, col = "#E37222", alpha = 0.7, auto.contour = FALSE, ...)
 {
   
-  # reset working directory 
-  wd <- getwd()
-  on.exit(setwd(wd))
+  # reset warnings
   on.exit(options(warn = .Options$warn), add = TRUE)
   
   #### set arguments from options
@@ -164,13 +159,13 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
   
   
   #check path to working directory
-  if (is.null(path)) path <- getwd() else {if (!dir.exists(path)) stop("'path' provided does not exist") else
-    setwd(path)
-  }  
+  if (is.null(path)) path <- getwd() else 
+    if (!dir.exists(path)) 
+      stop("'path' provided does not exist") 
   
   # no autonext if ts.df provided
   if (auto.next & !is.null(ts.df)) {
-    cat("'auto.next' not available when 'ts.df' is provided") 
+    write(file = "", x = "'auto.next' not available when 'ts.df' is provided") 
     auto.next <- FALSE
   }
   
@@ -214,13 +209,13 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
   if (all(class(X$end) != "numeric" & class(X$start) != "numeric")) stop("'start' and 'end' must be numeric")
   
   #if any start higher than end stop
-  if (any(X$end - X$start<0)) stop(paste("The start is higher than the end in", length(which(X$end - X$start<0)), "case(s)"))
+  if (any(X$end - X$start <= 0)) stop(paste("Start is higher than or equal to end in", length(which(X$end - X$start <= 0)), "case(s)"))
   
   #check title columns
   if (any(!title %in% names(X))) stop(paste('title column(s)', title[!title %in% names(X)], "not found"))
   
   # stop if not all sound files were found
-  fs <- list.files(pattern = "\\.wav$", ignore.case = TRUE)
+  fs <- list.files(path = path,pattern = "\\.wav$", ignore.case = TRUE)
   if (length(unique(X$sound.files[(X$sound.files %in% fs)])) != length(unique(X$sound.files))) 
     stop(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% fs)])), 
                ".wav file(s) not found"))
@@ -235,19 +230,28 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
   if (!is.null(index))   X$tailored[!1:nrow(X) %in% index] <- "y"
   write.csv(droplevels(X[X$tailored != "delete", ]), "seltailor_output.csv", row.names =  FALSE)  
   } else {
-    X <- read.csv("seltailor_output.csv", stringsAsFactors = FALSE)  
-  if (any(is.na(X$tailored))) X$tailored[is.na(X$tailored)] <-""
-  if (all(any(!is.na(X$tailored)),nrow(X[X$tailored %in% c("y", "delete"),]) == nrow(X))) {
-    options(show.error.messages=FALSE)
-    cat("all selections have been analyzed")
-    stop() 
-  }
+    # tell user file already existed
+    write(file = "", x = "'seltailor_output.csv' found in working directory, resuming tailoring ...")
+
+        X <- read.csv(file.path(path, "seltailor_output.csv"), stringsAsFactors = FALSE)  
   
-  if(!is.null(ts.df))
-  {
-    # ncl <- intersect(names(ts.df2), names(X))
-    ncl <- ncl[!ncl %in% c("sound.files", "selec")]
-  }
+        if(!is.null(ts.df))
+          if (any(!names(ts.df) %in% names(X)))
+            stop("'seltailor_output.csv' file in working directory does not contain frequency contour columns")  
+        
+        
+        
+        if (any(is.na(X$tailored))) X$tailored[is.na(X$tailored)] <-""
+  if (all(any(!is.na(X$tailored)),nrow(X[X$tailored %in% c("y", "delete"),]) == nrow(X))) {
+    
+    write(file = "", x = "all selections have been analyzed")
+    stop() 
+  } 
+        if(!is.null(ts.df))
+        {
+          # ncl <- intersect(names(ts.df2), names(X))
+          ncl <- ncl[!ncl %in% c("sound.files", "selec")]
+        }
   }
   
   dn <- 1:nrow(X)
@@ -270,7 +274,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
     j <- dn[h]
     
     if (exists("prev.plot")) rm(prev.plot)
-    rec <- tuneR::readWave(as.character(X$sound.files[j]), header = TRUE)
+    rec <- warbleR::read_wave(X$sound.files[j], path = path, header = TRUE)
     main <- do.call(paste, as.list(X[j, names(X) %in% title])) 
     
     f <- rec$sample.rate #for spectro display
@@ -289,7 +293,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
     par(mfrow = c(1,1), mar = c(3, 3, 1.8, 0.1))
     
     #create spectrogram
-    spectro_wrblr_int(tuneR::readWave(as.character(X$sound.files[j]),from =  tlim[1], to = tlim[2], units = "seconds"), 
+    spectro_wrblr_int(warbleR::read_wave(X = X$sound.files[j], path = path, from =  tlim[1], to = tlim[2]), 
                       f = f, wl = wl, ovlp = ovlp, wn = wn, heights = c(3, 2), 
                       osc = osci, palette =  pal, main = NULL, axisX= TRUE, grid = FALSE, collab = "black", alab = "", fftw= TRUE, colwave = "#07889B", collevels = collevels,
                       flim = fl, scale = FALSE, axisY= TRUE, fast.spec = fast.spec, 
@@ -370,8 +374,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
         #return X
         return(droplevels(X[X$tailored != "delete", ]))
         
-        options(show.error.messages=FALSE)
-        cat("all selections have been analyzed")
+        write(file = "", x = "all selections have been analyzed")
         stop() 
       } 
       h <- h + 1
@@ -382,7 +385,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
     {    
       h <- h - 1
       if (h == 0) {h <- 1
-      cat("These selection was the first one during the selection procedure (can't go further back)")
+      write(file = "", x = "These selection was the first one during the selection procedure (can't go further back)")
       }
     }
     
@@ -397,8 +400,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
         #return X
         return(droplevels(X[X$tailored != "delete", ]))
         
-        options(show.error.messages=FALSE)
-        cat("all selections have been analyzed")
+        write(file = "", x = "all selections have been analyzed")
         stop() 
       } 
       h <- h + 1
@@ -413,8 +415,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
       #return X
       return(droplevels(X[X$tailored != "delete", ]))
       
-      options(show.error.messages=FALSE)
-      cat("Stopped by user")
+      write(file = "", x = "Stopped by user")
       stop() 
     } 
     
@@ -456,8 +457,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
           #return X
           return(droplevels(X[X$tailored != "delete", ]))
           
-          options(show.error.messages=FALSE)
-          cat("all selections have been analyzed")
+          write(file = "", x = "all selections have been analyzed")
           stop() 
         } else {
           h <- h + 1
@@ -470,7 +470,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
         h <- h - 1
         if (h == 0) {
           h <- 1
-          cat("These selection was the first one during the selection procedure (can't go further back)")
+          write(file = "", x = "These selection was the first one during the selection procedure (can't go further back)")
         }
         break
       }
@@ -488,7 +488,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
           return(droplevels(X[X$tailored != "delete", ]))
           
           options(show.error.messages=FALSE)
-          cat("all selections have been analyzed")
+          write(file = "", x = "all selections have been analyzed")
           stop() 
         } else  {
           h <- h + 1  
@@ -500,12 +500,12 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
       {dev.off()
         if (selcount > 0) X$tailored[j] <- "y"
         write.csv(droplevels(X[X$tailored != "delete", ]), "seltailor_output.csv", row.names =  FALSE)
-        options(show.error.messages=FALSE)
+      
         
         #return X
         return(droplevels(X[X$tailored != "delete", ]))
         
-        cat("Stopped by user")
+        write(file = "", x = "Stopped by user")
         stop()}
       
       if (exists("prev.plot")) xy2 <- locator(n = 1, type = "n")
@@ -549,8 +549,7 @@ seltailor <- function(X = NULL, wl = 512, flim = c(0,22), wn = "hanning", mar =
           #return X
           return(droplevels(X[X$tailored != "delete", ]))
           
-          options(show.error.messages=FALSE)
-          cat("all selections have been analyzed")
+          write(file = "", x = "all selections have been analyzed")
           stop() 
         } else {
           Sys.sleep(pause) 
